@@ -27,11 +27,20 @@
 #include <config.h>
 #include <glib.h>
 
+#ifndef G_OS_WIN32
+#include <sys/socket.h>
+#include <arpa/inet.h>
+#include <net/if.h>
+#include <ifaddrs.h>
+#endif
 #include "gssdp-socket-functions.h"
 #include "gssdp-socket-source.h"
 #include "gssdp-protocol.h"
 #include "gssdp-error.h"
 
+#include <string.h>
+#include <stdio.h>
+
 static void
 gssdp_socket_source_initable_init (gpointer g_iface,
                                    gpointer iface_data);
@@ -49,6 +58,7 @@ struct _GSSDPSocketSourcePrivate {
         GSSDPSocketSourceType type;
 
         char                 *host_ip;
+        char                 *device_name;
         guint                 ttl;
         guint                 port;
 };
@@ -58,7 +68,8 @@ enum {
     PROP_TYPE,
     PROP_HOST_IP,
     PROP_TTL,
-    PROP_PORT
+    PROP_PORT,
+    PROP_IFA_NAME
 };
 
 static void
@@ -113,6 +124,9 @@ gssdp_socket_source_set_property (GObject          *object,
         case PROP_HOST_IP:
                 self->priv->host_ip = g_value_dup_string (value);
                 break;
+        case PROP_IFA_NAME:
+                self->priv->device_name = g_value_dup_string (value);
+                break;
         case PROP_TTL:
                 self->priv->ttl = g_value_get_uint (value);
                 break;
@@ -134,6 +148,7 @@ GSSDPSocketSource *
 gssdp_socket_source_new (GSSDPSocketSourceType type,
                          const char           *host_ip,
                          guint                 ttl,
+                         const char           *device_name,
                          GError              **error)
 {
         return g_initable_new (GSSDP_TYPE_SOCKET_SOURCE,
@@ -145,6 +160,8 @@ gssdp_socket_source_new (GSSDPSocketSourceType type,
                                host_ip,
                                "ttl",
                                ttl,
+                               "device-name",
+                               device_name,
                                NULL);
 }
 
@@ -202,12 +219,15 @@ gssdp_socket_source_do_init (GInitable                   *initable,
         }
 
         /* Enable broadcasting */
-        if (!gssdp_socket_enable_broadcast (self->priv->socket,
-                                            TRUE,
-                                            &inner_error)) {
+        g_socket_set_broadcast (self->priv->socket, TRUE);
+
+        if (!gssdp_socket_enable_info (self->priv->socket,
+                                       TRUE,
+                                       &inner_error)) {
                 g_propagate_prefixed_error (error,
                                             inner_error,
-                                            "Failed to enable broadcast");
+                                            "Failed to enable info messages");
+
                 goto error;
         }
 
@@ -216,29 +236,13 @@ gssdp_socket_source_do_init (GInitable                   *initable,
                 /* UDA/1.0 says 4, UDA/1.1 says 2 */
                 self->priv->ttl = 4;
 
-        if (!gssdp_socket_set_ttl (self->priv->socket,
-                                   self->priv->ttl,
-                                   &inner_error)) {
-                g_propagate_prefixed_error (error,
-                                            inner_error,
-                                            "Failed to set TTL to %u", self->priv->ttl);
+        g_socket_set_multicast_ttl (self->priv->socket, 4);
 
-                goto error;
-        }
 
         /* Set up additional things according to the type of socket desired */
         if (self->priv->type == GSSDP_SOCKET_SOURCE_TYPE_MULTICAST) {
                 /* Enable multicast loopback */
-                if (!gssdp_socket_enable_loop (self->priv->socket,
-                                               TRUE,
-                                               &inner_error)) {
-                        g_propagate_prefixed_error (
-                                        error,
-                                        inner_error,
-                                        "Failed to enable loop-back");
-
-                        goto error;
-                }
+                g_socket_set_multicast_loopback (self->priv->socket, TRUE);
 
                 if (!gssdp_socket_mcast_interface_set (self->priv->socket,
                                                        iface_address,
@@ -299,11 +303,13 @@ gssdp_socket_source_do_init (GInitable                   *initable,
         }
 
         if (self->priv->type == GSSDP_SOCKET_SOURCE_TYPE_MULTICAST) {
-
-                 /* Subscribe to multicast channel */
-                if (!gssdp_socket_mcast_group_join (self->priv->socket,
+                /* The 4th argument 'iface_name' can't be NULL even though Glib API doc says you
+                 * can. 'NULL' will fail the test.
+                 */
+                if (!g_socket_join_multicast_group (self->priv->socket,
                                                     group,
-                                                    iface_address,
+                                                    FALSE,
+                                                    self->priv->device_name,  /*   e.g. 'lo' */
                                                     &inner_error)) {
                         char *address = g_inet_address_to_string (group);
                         g_propagate_prefixed_error (error,
@@ -375,8 +381,8 @@ gssdp_socket_source_dispose (GObject *object)
         self = GSSDP_SOCKET_SOURCE (object);
 
         if (self->priv->source != NULL) {
-                g_source_unref (self->priv->source);
                 g_source_destroy (self->priv->source);
+                g_source_unref (self->priv->source);
                 self->priv->source = NULL;
         }
 
@@ -401,6 +407,11 @@ gssdp_socket_source_finalize (GObject *object)
                 self->priv->host_ip = NULL;
         }
 
+        if (self->priv->device_name != NULL) {
+                g_free (self->priv->device_name);
+                self->priv->device_name = NULL;
+        }
+
         G_OBJECT_CLASS (gssdp_socket_source_parent_class)->finalize (object);
 }
 
@@ -444,6 +455,18 @@ gssdp_socket_source_class_init (GSSDPSocketSourceClass *klass)
                          G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |
                          G_PARAM_STATIC_BLURB));
 
+        g_object_class_install_property
+                (object_class,
+                 PROP_IFA_NAME,
+                 g_param_spec_string
+                        ("device-name",
+                         "Interface name",
+                         "Name of associated network interface",
+                         NULL,
+                         G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY |
+                         G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |
+                         G_PARAM_STATIC_BLURB));
+
         g_object_class_install_property
                 (object_class,
                  PROP_TTL,
